@@ -123,11 +123,13 @@ const char *noframes_end	= "</noframes>";
 /** @name tree view tag (--tree-view) */
 /** @{ */
 const char *tree_control	= "<div id='control'>All <a href='#'>close</a> | <a href='#'>open</a></div>";
+const char *tree_loading	= "<span id='init' class='loading'>Under construction...</span>";
 const char *tree_begin		= "<ul id='tree'>";
 const char *tree_begin_using	= "<ul id='tree' class='%s'>";
 const char *tree_end		= "</ul>";
-const char *dir_begin		= "<li><span class='folder'></span>";
-const char *dir_end		= "";
+const char *dir_begin		= "<li><span class='folder'>";
+const char *dir_title_end	= "</span>";
+const char *dir_end		= "</li>";
 const char *file_begin		= "<li><span class='file'>";
 const char *file_end		= "</span></li>";
 /** @} */
