@@ -13,11 +13,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -59,18 +55,17 @@ static char sccsid[] = "@(#)bt_put.c	8.8 (Berkeley) 7/26/94";
 
 static EPG *bt_fast(BTREE *, const DBT *, const DBT *, int *);
 
-/*
+/**
  * __BT_PUT -- Add a btree item to the tree.
  *
- * Parameters:
- *	dbp:	pointer to access method
- *	key:	key
- *	data:	data
- *	flag:	R_NOOVERWRITE
+ *	@param dbp	pointer to access method
+ *	@param key	key
+ *	@param data	data
+ *	@param flags	#R_NOOVERWRITE
  *
- * Returns:
- *	RET_ERROR, RET_SUCCESS and RET_SPECIAL if the key is already in the
- *	tree and R_NOOVERWRITE specified.
+ * @return
+ *	#RET_ERROR, #RET_SUCCESS and #RET_SPECIAL if the key is already in the
+ *	tree and #R_NOOVERWRITE specified.
  */
 int
 __bt_put(dbp, key, data, flags)
@@ -259,15 +254,15 @@ success:
 
 u_long bt_cache_hit, bt_cache_miss;
 
-/*
+/**
  * BT_FAST -- Do a quick check for sorted data.
  *
- * Parameters:
- *	t:	tree
- *	key:	key to insert
+ *	@param t	tree
+ *	@param key	key to insert
+ *	@param data
+ *	@param exactp
  *
- * Returns:
- * 	EPG for new record or NULL if not found.
+ * @return #EPG for new record or @CODE{NULL} if not found.
  */
 static EPG *
 bt_fast(t, key, data, exactp)
