@@ -13,11 +13,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -54,21 +50,20 @@ static char sccsid[] = "@(#)bt_utils.c	8.8 (Berkeley) 7/20/94";
 #include "db.h"
 #include "btree.h"
 
-/*
+/**
  * __bt_ret --
  *	Build return key/data pair.
  *
- * Parameters:
- *	t:	tree
- *	e:	key/data pair to be returned
- *	key:	user's key structure (NULL if not to be filled in)
- *	rkey:	memory area to hold key
- *	data:	user's data structure (NULL if not to be filled in)
- *	rdata:	memory area to hold data
- *       copy:	always copy the key/data item
+ *	@param t	tree
+ *	@param e	key/data pair to be returned
+ *	@param key	user's key structure (@CODE{NULL} if not to be filled in)
+ *	@param rkey	memory area to hold @a key
+ *	@param data	user's data structure (@CODE{NULL} if not to be filled in)
+ *	@param rdata	memory area to hold @a data
+ *	@param copy	always copy the key/data item
  *
- * Returns:
- *	RET_SUCCESS, RET_ERROR.
+ * @return
+ *	#RET_SUCCESS, #RET_ERROR.
  */
 int
 __bt_ret(t, e, key, rkey, data, rdata, copy)
@@ -143,18 +138,17 @@ dataonly:
 	return (RET_SUCCESS);
 }
 
-/*
+/**
  * __BT_CMP -- Compare a key to a given record.
  *
- * Parameters:
- *	t:	tree
- *	k1:	DBT pointer of first arg to comparison
- *	e:	pointer to EPG for comparison
+ *	@param t	tree
+ *	@param k1	#DBT pointer of first arg to comparison
+ *	@param e	pointer to #EPG for comparison
  *
- * Returns:
- *	< 0 if k1 is < record
- *	= 0 if k1 is = record
- *	> 0 if k1 is > record
+ * @return
+ *	\< 0 if @a k1 is \< record <br>
+ *	= 0 if @a k1 is = record <br>
+ *	\> 0 if @a k1 is \> record
  */
 int
 __bt_cmp(t, k1, e)
@@ -207,17 +201,16 @@ __bt_cmp(t, k1, e)
 	return ((*t->bt_cmp)(k1, &k2));
 }
 
-/*
+/**
  * __BT_DEFCMP -- Default comparison routine.
  *
- * Parameters:
- *	a:	DBT #1
- *	b: 	DBT #2
+ *	@param a	#DBT \#1
+ *	@param b 	#DBT \#2
  *
- * Returns:
- *	< 0 if a is < b
- *	= 0 if a is = b
- *	> 0 if a is > b
+ * @return
+ *	\< 0 if @a a is \< @a b <br>
+ *	= 0 if @a a is = @a b <br>
+ *	\> 0 if @a a is \> @a b
  */
 int
 __bt_defcmp(a, b)
@@ -239,15 +232,14 @@ __bt_defcmp(a, b)
 	return ((int)a->size - (int)b->size);
 }
 
-/*
+/**
  * __BT_DEFPFX -- Default prefix routine.
  *
- * Parameters:
- *	a:	DBT #1
- *	b: 	DBT #2
+ *	@param a	#DBT \#1
+ *	@param b 	#DBT \#2
  *
- * Returns:
- *	Number of bytes needed to distinguish b from a.
+ * @return
+ *	Number of bytes needed to distinguish @a b from @a a.
  */
 size_t
 __bt_defpfx(a, b)
